# Generated by roxygen2: do not edit by hand

S3method(coef,lgspline)
S3method(coef,wald_lgspline)
S3method(confint,lgspline)
S3method(confint,wald_lgspline)
S3method(equation,additive_lgspline)
S3method(equation,lgspline)
S3method(integrate,default)
S3method(integrate,lgspline)
S3method(logLik,lgspline)
S3method(plot,lgspline)
S3method(plot,wald_lgspline)
S3method(predict,lgspline)
S3method(print,additive_lgspline)
S3method(print,equation)
S3method(print,lgspline)
S3method(print,summary.lgspline)
S3method(print,wald_lgspline)
S3method(summary,additive_lgspline)
S3method(summary,lgspline)
S3method(summary,wald_lgspline)
export("%**%")
export(AGAmult_wrapper)
export(GAmult_wrapper)
export(approx_grad)
export(armaInv)
export(blockfit_solve)
export(collapse_block_diagonal)
export(compute_G_eigen)
export(compute_GhalfXy_temp_wrapper)
export(compute_Lambda)
export(compute_dG_dlambda)
export(compute_dG_u_dlambda_xy)
export(compute_dGhalf)
export(compute_gram_block_diagonal)
export(compute_trace_H)
export(compute_trace_UGXX_wrapper)
export(cox_dispersion_function)
export(cox_family)
export(cox_glm_weight_function)
export(cox_qp_score_function)
export(cox_schur_correction)
export(create_block_diagonal)
export(create_onehot)
export(damped_newton_r)
export(efficient_bfgs)
export(efficient_matrix_mult)
export(equation)
export(expgrid)
export(find_extremum)
export(find_neighbors)
export(generate_posterior)
export(generate_posterior_correlation)
export(get_2ndDerivPenalty)
export(get_2ndDerivPenalty_wrapper)
export(get_B)
export(get_U)
export(get_centers)
export(get_interaction_patterns)
export(get_polynomial_expansions)
export(gramMatrix)
export(info_cox)
export(info_negbin)
export(integrate)
export(invert)
export(is_binary)
export(knot_expand_list)
export(leave_one_out)
export(lgspline)
export(lgspline.fit)
export(lgspline_cox)
export(lgspline_negbin)
export(lgspline_weibull)
export(loglik_cox)
export(loglik_negbin)
export(loglik_weibull)
export(make_constraint_matrix)
export(make_derivative_matrix)
export(make_partitions)
export(matinvsqrt)
export(matmult_U)
export(matmult_block_diagonal)
export(matsqrt)
export(negbin_dispersion_function)
export(negbin_family)
export(negbin_glm_weight_function)
export(negbin_qp_score_function)
export(negbin_schur_correction)
export(negbin_theta)
export(nr_iterate)
export(prior_loglik)
export(process_input)
export(process_qp)
export(reml_grad_from_dV)
export(score_cox)
export(score_negbin)
export(softplus)
export(std)
export(take_derivative)
export(take_interaction_2ndderivative)
export(tune_Lambda)
export(unconstrained_fit_cox)
export(unconstrained_fit_default)
export(unconstrained_fit_negbin)
export(unconstrained_fit_weibull)
export(vectorproduct_block_diagonal)
export(wald_univariate)
export(weibull_dispersion_function)
export(weibull_family)
export(weibull_glm_weight_function)
export(weibull_qp_score_function)
export(weibull_scale)
export(weibull_schur_correction)
export(weibull_shur_correction)
import(Rcpp)
import(methods)
import(stats)
importFrom(FNN,get.knnx)
importFrom(RColorBrewer,brewer.pal)
importFrom(Rcpp,sourceCpp)
importFrom(graphics,legend)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(plotly,plot_ly)
importFrom(quadprog,solve.QP)
useDynLib(lgspline)
