% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{confint.wald_lgspline}
\alias{confint.wald_lgspline}
\title{Extract Confidence Intervals from a wald_lgspline Object}
\usage{
\method{confint}{wald_lgspline}(object, parm = NULL, level = NULL, ...)
}
\arguments{
\item{object}{A \code{"wald_lgspline"} object.}

\item{parm}{Parameter specification (ignored; all returned).}

\item{level}{Confidence level (ignored; uses the object's critical value).}

\item{...}{Not used.}
}
\value{
Matrix with columns lower and upper, or NULL if confidence
  limits are not available.
}
\description{
Extract Confidence Intervals from a wald_lgspline Object
}
