% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{print.wald_lgspline}
\alias{print.wald_lgspline}
\title{Print Method for wald_lgspline Objects}
\usage{
\method{print}{wald_lgspline}(
  x,
  digits = max(3, getOption("digits") - 3),
  signif.stars = getOption("show.signif.stars"),
  ...
)
}
\arguments{
\item{x}{A \code{"wald_lgspline"} object from \code{\link{wald_univariate}}.}

\item{digits}{Number of significant digits.}

\item{signif.stars}{Logical; show significance stars.}

\item{...}{Additional arguments passed to \code{\link[stats]{printCoefmat}}.}
}
\value{
Invisibly returns \code{x}.
}
\description{
Prints the coefficient table using \code{\link[stats]{printCoefmat}} with
significance stars.
}
\seealso{
\code{\link{wald_univariate}}, \code{\link[stats]{printCoefmat}}
}
