% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/HelperFunctions.R
\name{compute_gram_block_diagonal}
\alias{compute_gram_block_diagonal}
\title{Compute Gram Matrix for Block Diagonal Structure}
\usage{
compute_gram_block_diagonal(
  list_in,
  parallel,
  cl,
  chunk_size,
  num_chunks,
  rem_chunks
)
}
\arguments{
\item{list_in}{List of matrices}

\item{parallel}{Use parallel processing}

\item{cl}{Cluster object}

\item{chunk_size}{Chunk size for parallel}

\item{num_chunks}{Number of chunks}

\item{rem_chunks}{Remaining chunks}
}
\value{
List of Gram matrices (\eqn{\textbf{X}^{T}\textbf{X}}) for each block
}
\description{
Compute Gram Matrix for Block Diagonal Structure
}
\details{
For a list of matrices, will compute the gram matrix of each element of the
list.
}
\keyword{internal}
