% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/HelperFunctions.R
\name{get_2ndDerivPenalty_wrapper}
\alias{get_2ndDerivPenalty_wrapper}
\title{Wrapper for Integrated Second-Derivative Penalty Computation}
\usage{
get_2ndDerivPenalty_wrapper(
  K,
  colnm_expansions,
  C,
  power1_cols,
  power2_cols,
  power3_cols,
  power4_cols,
  interaction_single_cols,
  interaction_quad_cols,
  triplet_cols,
  nonspline_cols,
  p_expansions,
  parallel,
  cl
)
}
\arguments{
\item{K}{Number of partitions (\eqn{K+1})}

\item{colnm_expansions}{Column names of basis expansions}

\item{C}{Basis expansion matrix used to determine observed predictor ranges}

\item{power1_cols}{Linear term columns}

\item{power2_cols}{Quadratic term columns}

\item{power3_cols}{Cubic term columns}

\item{power4_cols}{Quartic term columns}

\item{interaction_single_cols}{Single interaction columns}

\item{interaction_quad_cols}{Quadratic interaction columns}

\item{triplet_cols}{Triplet interaction columns}

\item{nonspline_cols}{Predictors not treated as spline effects}

\item{p_expansions}{Number of columns in the basis expansion per partition}

\item{parallel}{Logical to enable parallel processing}

\item{cl}{Cluster object for parallel computation}
}
\value{
A \eqn{p \times p} integrated squared second-derivative penalty
  matrix.
}
\description{
Computes the integrated squared second-derivative penalty matrix with
optional parallel processing.
}
\keyword{internal}
