% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/HelperFunctions.R
\name{get_interaction_patterns}
\alias{get_interaction_patterns}
\title{Generate Interaction Variable Patterns}
\usage{
get_interaction_patterns(vars)
}
\arguments{
\item{vars}{Character vector of variable names}
}
\value{
Character vector of interaction pattern strings for 2- or 3-variable
inputs, or \code{NULL} otherwise.
}
\description{
Generates all possible interaction patterns for 2 or 3 variables. This is
used in part for identifying which interactions and expansions to exclude
(provided to "exclude_these_expansions" argument of lgspline) based on
formulas provided.
}
\keyword{internal}
