% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/HelperFunctions.R
\name{is_binary}
\alias{is_binary}
\title{Test if Vector is Binary}
\usage{
is_binary(x)
}
\arguments{
\item{x}{Vector to test}
}
\value{
Logical indicating if x has at most 2 unique values
}
\description{
Test if Vector is Binary
}
\keyword{internal}
