% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/HelperFunctions.R
\name{collapse_block_diagonal}
\alias{collapse_block_diagonal}
\title{Collapse Matrix List into a Single Dense Block-Layout Matrix}
\usage{
collapse_block_diagonal(matlist)
}
\arguments{
\item{matlist}{List of input matrices}
}
\value{
Dense matrix with each input block placed in its own column range
}
\description{
Transforms a list of matrices into a single dense block-layout matrix. This
is useful especially for quadratic programming problems, where operating on
lists of blocks is not convenient.
}
\keyword{internal}
