% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{print.summary.lgspline}
\alias{print.summary.lgspline}
\title{Print Method for lgspline Summaries}
\usage{
\method{print}{summary.lgspline}(x, ...)
}
\arguments{
\item{x}{A \code{summary.lgspline} object.}

\item{...}{Not used.}
}
\value{
Invisibly returns \code{x}.
}
\description{
Displays a formatted model summary using \code{\link[stats]{printCoefmat}}
for the coefficient table.
}
\seealso{
\code{\link[stats]{printCoefmat}}
}
