% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{vectorproduct_block_diagonal}
\alias{vectorproduct_block_diagonal}
\title{Vector-Matrix Multiplication for Block Diagonal Matrices}
\usage{
vectorproduct_block_diagonal(A, b, K)
}
\arguments{
\item{A}{List of matrices A}

\item{b}{List of vectors b}

\item{K}{Number of blocks}
}
\value{
List of resulting vectors
}
\description{
Performs vector-matrix multiplication for block diagonal matrices
}
\keyword{internal}
