% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/HelperFunctions.R
\name{compute_GhalfXy_temp_wrapper}
\alias{compute_GhalfXy_temp_wrapper}
\title{Compute Component \eqn{\textbf{G}^{1/2}\textbf{A}(\textbf{A}^{T}\textbf{G}\textbf{A})^{-1}\textbf{A}^{T}\textbf{G}\textbf{X}^{T}\textbf{y}}}
\usage{
compute_GhalfXy_temp_wrapper(
  G,
  Ghalf,
  A,
  AGAInv,
  Xy,
  nc,
  K,
  parallel,
  cl,
  chunk_size,
  num_chunks,
  rem_chunks
)
}
\arguments{
\item{G}{List of \eqn{\textbf{G}} matrices}

\item{Ghalf}{List of \eqn{\textbf{G}^{1/2}} matrices}

\item{A}{Constraint matrix \eqn{\textbf{A}}}

\item{AGAInv}{Inverse of \eqn{\textbf{A}^{T}\textbf{G}\textbf{A}}}

\item{Xy}{List of \eqn{\textbf{X}^{T}\textbf{y}} products}

\item{nc}{Number of columns}

\item{K}{Number of partitions minus 1 (\eqn{K})}

\item{parallel}{Use parallel processing}

\item{cl}{Cluster object}

\item{chunk_size}{Size of parallel chunks}

\item{num_chunks}{Number of chunks}

\item{rem_chunks}{Remaining chunks}
}
\value{
Unnamed two-element list containing the projected result vector and
  the intermediate
  \eqn{(\mathbf{A}^{T}\mathbf{G}\mathbf{A})^{-1}\mathbf{A}^{T}\mathbf{G}\mathbf{X}^{T}\mathbf{y}}
  product.
}
\description{
Compute Component \eqn{\textbf{G}^{1/2}\textbf{A}(\textbf{A}^{T}\textbf{G}\textbf{A})^{-1}\textbf{A}^{T}\textbf{G}\textbf{X}^{T}\textbf{y}}
}
\details{
Computes the least-squares projection component
\eqn{\mathbf{G}^{1/2}\mathbf{A}(\mathbf{A}^{T}\mathbf{G}\mathbf{A})^{-1}
\mathbf{A}^{T}\mathbf{G}\mathbf{X}^{T}\mathbf{y}} together with the
intermediate product
\eqn{(\mathbf{A}^{T}\mathbf{G}\mathbf{A})^{-1}\mathbf{A}^{T}\mathbf{G}\mathbf{X}^{T}\mathbf{y}}
for reuse downstream.
}
\keyword{internal}
