% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/HelperFunctions.R
\name{GAmult_wrapper}
\alias{GAmult_wrapper}
\title{Efficient Matrix Multiplication of G and A Matrices}
\usage{
GAmult_wrapper(
  G,
  A,
  K,
  p_expansions,
  R_constraints,
  parallel,
  cl,
  chunk_size,
  num_chunks,
  rem_chunks
)
}
\arguments{
\item{G}{List of G matrices}

\item{A}{Constraint matrix}

\item{K}{Number of partitions minus 1}

\item{p_expansions}{Number of columns per partition}

\item{R_constraints}{Number of constraint columns}

\item{parallel}{Use parallel processing}

\item{cl}{Cluster object}

\item{chunk_size}{Size of parallel chunks}

\item{num_chunks}{Number of chunks}

\item{rem_chunks}{Remaining chunks}
}
\value{
List of matrix products, one per partition
}
\description{
Efficient Matrix Multiplication of G and A Matrices
}
\details{
Computes G %**% A when G has block diagonal structure and A is a matrix.
Processes in parallel chunks if enabled.
}
\keyword{internal}
