% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/HelperFunctions.R
\name{std}
\alias{std}
\title{Standardize Vector to Z-Scores}
\usage{
std(x)
}
\arguments{
\item{x}{Numeric vector to standardize}
}
\value{
Standardized vector with sample mean 0 and standard deviation 1
}
\description{
Centers a vector by its sample mean, then scales it by its sample standard deviation
\eqn{(\text{x}-\text{mean}(\text{x}))/\text{sd}(\text{x})}.
}
\examples{

x <- c(1, 2, 3, 4, 5)
std(x)
print(mean(x))
print(sd(x))


}
