% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{armaInv}
\alias{armaInv}
\title{Matrix Inversion using Armadillo}
\usage{
armaInv(x)
}
\arguments{
\item{x}{Input matrix to be inverted}
}
\value{
Inverted matrix
}
\description{
Computes the inverse of a matrix using Armadillo's inversion method
}
\keyword{internal}
