% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/HelperFunctions.R
\name{\%**\%}
\alias{\%**\%}
\title{Efficient Matrix Multiplication Operator}
\usage{
x \%**\% y
}
\arguments{
\item{x}{Left matrix}

\item{y}{Right matrix}
}
\value{
Matrix product of x and y
}
\description{
Operator wrapper around C++ \code{efficient_matrix_mult()} for matrix multiplication syntax.

This is an internal function meant to provide improvement over base R's operator for
certain large matrix operations, at a cost of potential slight slowdown for
smaller problems.
}
\examples{

M1 <- matrix(1:4, 2, 2)
M2 <- matrix(5:8, 2, 2)
M1 \%**\% M2


}
\keyword{internal}
