% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{summary.wald_lgspline}
\alias{summary.wald_lgspline}
\title{Summary Method for wald_lgspline Objects}
\usage{
\method{summary}{wald_lgspline}(object, ...)
}
\arguments{
\item{object}{A \code{"wald_lgspline"} object.}

\item{...}{Passed to \code{\link{print.wald_lgspline}}.}
}
\value{
Invisibly returns \code{object}.
}
\description{
Prints a header with model info then delegates to
\code{\link{print.wald_lgspline}}.
}
\seealso{
\code{\link{wald_univariate}}, \code{\link{print.wald_lgspline}}
}
