% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{gramMatrix}
\alias{gramMatrix}
\title{Compute Gram Matrix}
\usage{
gramMatrix(X)
}
\arguments{
\item{X}{Input matrix}
}
\value{
Gram matrix (X^T * X)
}
\description{
Calculates X^T * X for the input matrix X
}
\keyword{internal}
