% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{efficient_matrix_mult}
\alias{efficient_matrix_mult}
\title{Efficient Matrix Multiplication}
\usage{
efficient_matrix_mult(A, B)
}
\arguments{
\item{A}{First input matrix}

\item{B}{Second input matrix}
}
\value{
Matrix product of A and B
}
\description{
Performs matrix multiplication using RcppArmadillo
}
\keyword{internal}
