% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppExports.R
\name{matmult_U}
\alias{matmult_U}
\title{Left-Multiply a List of Block-Diagonal Matrices by U}
\usage{
matmult_U(U, G, nc, K)
}
\arguments{
\item{U}{Matrix of dimension P by P that projects onto the null space of A transpose}

\item{G}{List of G matrices for each partition}

\item{nc}{Numeric numeric of basis expansions of predictors per partition}

\item{K}{Number of blocks}
}
\value{
Matrix of UG
}
\description{
Useful for computing UG where G is a list of block-diagonal matrices for each partition, and U is a square P by P dense matrix
}
\keyword{internal}
