% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/HelperFunctions.R
\name{compute_dG_dlambda}
\alias{compute_dG_dlambda}
\title{Compute Derivative of Inverse-Information Matrix G with Respect to Lambda}
\usage{
compute_dG_dlambda(
  G,
  dPenalty_dlambda,
  K,
  unique_penalty_per_partition,
  dPenalty_partition_list,
  parallel,
  cl,
  chunk_size,
  num_chunks,
  rem_chunks
)
}
\arguments{
\item{G}{A list of inverse-information matrices \eqn{\textbf{G}} for each
partition}

\item{dPenalty_dlambda}{Derivative of the shared penalty matrix with
respect to \eqn{\lambda}.}

\item{K}{Number of partitions minus 1 (\eqn{K})}

\item{unique_penalty_per_partition}{Logical indicating partition-specific penalties}

\item{dPenalty_partition_list}{Optional list of derivatives of the
partition-specific penalty matrices with respect to \eqn{\lambda}.}

\item{parallel}{Logical to enable parallel processing}

\item{cl}{Cluster object for parallel computation}

\item{chunk_size}{Size of chunks for parallel processing}

\item{num_chunks}{Number of chunks}

\item{rem_chunks}{Remainder chunks}
}
\value{
A list of derivative matrices \eqn{d\textbf{G}/d\lambda} for each partition
}
\description{
Calculates the derivative of the inverse-information matrix
\eqn{\textbf{G}} with respect to the smoothing parameter \eqn{\lambda},
supporting both shared and partition-specific penalties.
}
\keyword{internal}
