% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{coef.wald_lgspline}
\alias{coef.wald_lgspline}
\title{Extract Coefficients from a wald_lgspline Object}
\usage{
\method{coef}{wald_lgspline}(object, ...)
}
\arguments{
\item{object}{A \code{"wald_lgspline"} object.}

\item{...}{Not used.}
}
\value{
Named numeric vector of coefficient estimates, or NULL if no
  estimate column is available.
}
\description{
Extract Coefficients from a wald_lgspline Object
}
