% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/HelperFunctions.R
\name{softplus}
\alias{softplus}
\title{Compute softplus transform}
\usage{
softplus(x)
}
\arguments{
\item{x}{Numeric vector to apply softplus to}
}
\value{
Softplus transformed vector
}
\description{
Computes the softplus transform, equivalent to the cumulant generating function
of a logistic regression model: \eqn{\log(1+e^x)}.
}
\examples{

x <- runif(5)
softplus(x)


}
\keyword{internal}
