% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/HelperFunctions.R
\name{.rank_dists}
\alias{.rank_dists}
\title{Compute rank-based distance matrix for AR(1) structures}
\usage{
.rank_dists(spacetime, inds)
}
\description{
Converts the unique within-block distances returned by
\code{.compute_dist_block()} to integer lags \code{0, 1, 2, \ldots} in
increasing order.
}
\keyword{internal}
