% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{summary.lgspline}
\alias{summary.lgspline}
\title{Summary Method for lgspline Objects}
\usage{
\method{summary}{lgspline}(object, ...)
}
\arguments{
\item{object}{An lgspline model object.}

\item{...}{Not used.}
}
\value{
An object of class \code{summary.lgspline}, a list containing:
\describe{
  \item{model_family}{The \code{\link[stats]{family}} object.}
  \item{observations}{Number of observations N.}
  \item{predictors}{Number of predictor variables q.}
  \item{knots}{Number of knots K.}
  \item{basis_functions}{Basis functions per partition p.}
  \item{estimate_dispersion}{"Yes" or "No".}
  \item{cv}{Critical value used for confidence intervals.}
  \item{coefficients}{Coefficient matrix from \code{\link{wald_univariate}},
        or a single-column estimate matrix if \code{return_varcovmat = FALSE}.}
  \item{sigmasq_tilde}{Estimated dispersion \eqn{\tilde{\sigma}^2}.}
  \item{trace_XUGX}{Trace of the hat matrix \eqn{\mathrm{trace}(\mathbf{XUGX}^\top)}.}
  \item{N}{Number of observations.}
}
}
\description{
Summary Method for lgspline Objects
}
